%global toolchain clang

#Yaked from gentoo
%global optflags %{optflags} -DFMT_CONSTEVAL=

Name:           pcsx2
Version:        2.2.0
Release:        %mkrel 3
Summary:        Playstation 2 console emulator
License:        GPLv3 and LGPLv3
Group:          Emulators
Url:            https://github.com/PCSX2/pcsx2
Source0:        https://github.com/PCSX2/pcsx2/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/PCSX2/pcsx2_patches/archive/latest.tar.gz?/pcsx-patches.tar.gz

Patch0:         pcsx2-shaderc.patch
Patch1:         pcsx2-unique-lock.patch

ExclusiveArch:  x86_64

BuildRequires:  cmake
BuildRequires:  cmake(ECM)
BuildRequires:  clang
BuildRequires:  lld
BuildRequires:  llvm
BuildRequires:  gettext
BuildRequires:  ninja
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Designer)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(PulseAudio)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xdmcp)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswresample)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libbacktrace)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libffi)
BuildRequires:  pkgconfig(libidn2)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(liblz4)
BuildRequires:  pkgconfig(libpcap)
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(shaderc)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  libaio-devel

%description
PCSX2 is an emulator for the playstation 2 video game console. It is written
mostly in C++, some part are in C and x86 assembly. There is still lot of on
going work to improve compatibility & speed.

%prep
%autosetup -p1 -a1

mv pcsx2_patches-latest/patches ./
#rm -rf 3rdparty

#Taked fro AUR
# prevent march=native
sed -E -e 's@^(\s*)(add_compile_options\(.*march=native.*\))@\1message("skip: march=native")@' \
-i cmake/BuildParameters.cmake

# adjust data path
sed -E -e '/CMAKE_INSTALL_FULL_DATADIR/s@/PCSX2\b@/'"%{name}@" \
-i "pcsx2/CMakeLists.txt" \
"cmake/BuildParameters.cmake"

%build
%cmake \
  -GNinja \
  -DCMAKE_LINKER_TYPE=LLD \
  -DPACKAGE_MODE:BOOL=ON \
  -DBUILD_SHARED_LIBS:BOOL=OFF \
  -DX11_API:BOOL=ON \
  -DWAYLAND_API:BOOL=ON \
  -DENABLE_TESTS:BOOL=OFF \
  -DDISABLE_ADVANCE_SIMD:BOOL=ON
%cmake_build

%install
%cmake_install

install -Dp -m0644 %{name}-qt/resources/icons/AppIcon64.png %{buildroot}%{_iconsdir}/hicolor/64x64/apps/PCSX2.png
install -Dp -m0644 bin/resources/icons/AppIconLarge.png %{buildroot}%{_iconsdir}/hicolor/512x512/apps/PCSX2.png
install -Dp -m0644 .github/workflows/scripts/linux/%{name}-qt.desktop %{buildroot}%{_datadir}/applications/%{name}-qt.desktop

mkdir -p %{buildroot}%{_datadir}/%{name}/resources
cp -a patches %{buildroot}%{_datadir}/%{name}/resources/

%files
%doc bin/docs/*.pdf
%caps(cap_net_admin,cap_net_raw=eip) %{_bindir}/pcsx2-qt
%{_datadir}/applications/pcsx2-qt.desktop
%{_datadir}/pcsx2/
%{_iconsdir}/hicolor/*/apps/PCSX2.png


%changelog
* Thu Jul 03 2025 umeabot <umeabot> 2.2.0-3.mga10
+ Revision: 2244454
- Mageia 10 Mass Rebuild

* Sun Jun 15 2025 wally <wally> 2.2.0-2.mga10.tainted
+ Revision: 2191599
- fix resources dir
- enable net access via capabilities
- own unowned /usr/share/pcsx2 directory
- properly build using clang toolchain

* Sun Jun 15 2025 katnatek <katnatek> 2.2.0-1.mga10.tainted
+ Revision: 2191392
- Update to version 2.2.0
- Fix update request mga#34227

* Wed Jan 26 2022 akien <akien> 1.6.0-2.mga9.tainted
+ Revision: 1769846
- Rebuild for new SoundTouch

* Sat May 09 2020 akien <akien> 1.6.0-1.mga8.tainted
+ Revision: 1582394
- Version 1.6.0
+ wally <wally>
- build with new cmake macros

* Wed Sep 18 2019 daviddavid <daviddavid> 1.5.0-0.20190505.2.mga8.tainted
+ Revision: 1443454
- rebuild against wxgtk with gtk3 enabled

* Fri May 10 2019 akien <akien> 1.5.0-0.20190505.1.mga7.tainted
+ Revision: 1396983
- Update to current Git snapshot to fix build with GCC 8
- Build against SDL2
+ daviddavid <daviddavid>
- Mageia 7 Mass Rebuild

* Fri Jun 03 2016 akien <akien> 1.4.0-3.mga6.tainted
+ Revision: 1020193
- Upstream patch to fix build with gcc6 (and apparently 5.4 too for us)
- Rebuild against wxGTK+ 3.0 with GTK+2 API
- Build against wxgtk3.0 (recommended) and thus GTK+3 for us (experimental)

* Sat Jan 16 2016 akien <akien> 1.4.0-2.mga6.tainted
+ Revision: 924755
- Set XDG_STD mode in the build options

* Fri Jan 15 2016 akien <akien> 1.4.0-1.mga6.tainted
+ Revision: 923308
- import pcsx2 based on a ROSA source package

